const viewerSettings = {
  toolbarEnabled:       {{enable_toolbar}},
  linkBlockingEnabled:  {{enable_link_blocking}},
  libraryButtonEnabled: {{enable_library_button}}
}
